pub struct Watchdog<'d> { /* private fields */ }Expand description
Watchdog peripheral
Implementations
Sourceimpl<'d> Watchdog<'d>
impl<'d> Watchdog<'d>
Sourcepub fn enable_tick_generation(&mut self, cycles: u8)
pub fn enable_tick_generation(&mut self, cycles: u8)
Start tick generation on clk_tick which is driven from clk_ref.
Arguments
cycles- Total number of tick cycles before the next tick is generated. It is expected to be the frequency in MHz of clk_ref.
Sourcepub fn pause_on_debug(&mut self, pause: bool)
pub fn pause_on_debug(&mut self, pause: bool)
Defines whether or not the watchdog timer should be paused when processor(s) are in debug mode or when JTAG is accessing bus fabric
Sourcepub fn trigger_reset(&mut self)
pub fn trigger_reset(&mut self)
Trigger a system reset
Sourcepub fn set_scratch(&mut self, index: usize, value: u32)
pub fn set_scratch(&mut self, index: usize, value: u32)
Store data in scratch register
Sourcepub fn reset_reason(&self) -> Option<ResetReason>
pub fn reset_reason(&self) -> Option<ResetReason>
Get the reason for the last system reset, if it was caused by the watchdog.